@@ -1,15 +1,11 @@
 # Programmer friendly subprocess wrapper.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: May 24, 2015
+# Last Change: October 1, 2015
 # URL: https://executor.readthedocs.org
 
 """
-The :mod:`executor.compat` module
-=================================
-
-Simple tools to make it easier to write Python code that is compatible with
-Python 2 as well as Python 3.
+Some aliases to make it easier to support both Python 2 and 3.
 
 .. class:: basestring
 
@@ -27,17 +23,16 @@ Python 2 as well as Python 3.
    in Python 3.
 """
 
-# Standard library modules.
-import sys
 
-if sys.version_info[0] == 2:
-    # Enable importing of basestring from this module.
+try:
+    # Enable importing of basestring from this module. This will raise
+    # NameError on Python 3 because basestring is no longer available.
     basestring = basestring
     # Alias bytes to str.
     bytes = str
     # Alias str to unicode.
     str = unicode
-elif sys.version_info[0] == 3:
+except NameError:
     # Alias basestring to str.
     basestring = str
     # Enable importing of bytes and str from this module.
